@@ -1,5 +1,5 @@
 package Parse::HTTP::UserAgent::Base::Parsers;
-$Parse::HTTP::UserAgent::Base::Parsers::VERSION = '0.42';
+$Parse::HTTP::UserAgent::Base::Parsers::VERSION = '0.43';
 use strict;
 use warnings;
 use Parse::HTTP::UserAgent::Constants qw(:all);
@@ -949,7 +949,7 @@ Parse::HTTP::UserAgent::Base::Parsers
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -959,13 +959,17 @@ Internal module.
 
 Parse::HTTP::UserAgent::Base::Parsers - Base class
 
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED>. Please use L<HTTP::BrowserDetect> instead.
+
 =head1 SEE ALSO
 
 L<Parse::HTTP::UserAgent>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
